
# Slot: address


the particulars of the place where someone or an organization is situated.  For now, this slot is a simple text "blob" containing all relevant details of the given location for fitness of purpose. For the moment, this "address" can include other contact details such as email and phone number(?).

URI: [biolink:address](https://w3id.org/biolink/vocab/address)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [Agent](Agent.md)
